@@ -3,6 +3,7 @@
  *
  *      Copyright 2010 Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
  *      Copyright 2012-2015 Andriy Grytsenko (LStranger) <andrej@rep.kiev.ua>
+ *      Copyright 2020 wb9688 <wb9688@users.noreply.github.com>
  *
  *      This file is a part of the Libfm library.
  *
@@ -214,7 +215,6 @@ static char* expand_exec_macros(GAppInfo* app, const char* full_desktop_path,
 
 struct ChildSetup
 {
-    char* display;
     char* sn_id;
     pid_t pgid;
 };
@@ -222,8 +222,6 @@ struct ChildSetup
 static void child_setup(gpointer user_data)
 {
     struct ChildSetup* data = (struct ChildSetup*)user_data;
-    if(data->display)
-        g_setenv ("DISPLAY", data->display, TRUE);
     if(data->sn_id)
         g_setenv ("DESKTOP_STARTUP_ID", data->sn_id, TRUE);
     /* Move child to grandparent group so it will not die with parent */
@@ -340,7 +338,6 @@ static gboolean do_launch(GAppInfo* appinfo, const char* full_desktop_path,
             }
             else
                 use_sn = FALSE;
-            data.display = g_app_launch_context_get_display(ctx, appinfo, gfiles);
 
             if(use_sn)
                 data.sn_id = g_app_launch_context_get_startup_notify_id(ctx, appinfo, gfiles);
@@ -348,10 +345,8 @@ static gboolean do_launch(GAppInfo* appinfo, const char* full_desktop_path,
                 data.sn_id = NULL;
         }
         else
-        {
-            data.display = NULL;
             data.sn_id = NULL;
-        }
+
         g_debug("sn_id = %s", data.sn_id);
 
         if(G_LIKELY(kf))
@@ -372,7 +367,6 @@ static gboolean do_launch(GAppInfo* appinfo, const char* full_desktop_path,
             g_app_launch_context_launch_failed(ctx, data.sn_id);
 
         g_free(path);
-        g_free(data.display);
         g_free(data.sn_id);
 
         g_strfreev(argv);
