@@ -35,7 +35,7 @@
 #include <glib/gi18n-lib.h>
 #include "fm.h"
 
-#ifdef HAVE_ACTIONS
+#ifdef HAVE_OLD_ACTIONS
 #include "actions/fm-actions.h"
 #endif
 
@@ -123,7 +123,7 @@ gboolean fm_init(FmConfig* config)
     _fm_templates_init();
     _fm_folder_config_init();
 
-#ifdef HAVE_ACTIONS
+#ifdef HAVE_OLD_ACTIONS
 	/* generated by vala */
     _fm_file_actions_init();
 #endif
@@ -148,7 +148,7 @@ void fm_finalize(void)
     if (!g_atomic_int_dec_and_test(&init_done))
         return;
 
-#ifdef HAVE_ACTIONS
+#ifdef HAVE_OLD_ACTIONS
 	/* generated by vala */
     _fm_file_actions_finalize();
 #endif
